
![image (4)](https://github.com/nagvalhm/epure/assets/20476975/a43decba-91a9-49d9-97ba-baa851cf044c)

<p align="center">
    <em>New way to store data, smart query constructor, concise syntax</em>
</p>

---

**Documentation**: <a href="https://epurelib.github.io/latest/" target="_blank">https://epurelib.github.io/latest/</a>

**Source Code**: <a href="https://github.com/nagvalhm/epure" target="_blank">https://github.com/nagvalhm/epure</a>

**PyPI**: <a href="https://pypi.org/project/epure/" target="_blank">https://pypi.org/project/epure/</a>

---

Epure is python type-hints based ORM - you can store and retrieve data having no idea about database, table and columns. 
All technical details hidden from you. Care only about your business logic 🤑.

Key features:

<!-- * **Concise**: Magic way to build flexible and smart queries -->
<!-- * **Concise**: Shortest way to build :magic_wand: _magic_ :magic_wand: queries -->
<!-- * **Concise**: Straight-to-the-point building :magic_wand: _magic_ :magic_wand: queries -->
<!-- * **Concise**: Straight-to-the-point way of building queries -->
<!-- * **Concise**: Smartest way in building :magic_wand: _magic_ :magic_wand: queries -->
<!-- * **Lightweight structure**: Contrary to other python ORM - in Epure you have freedom to make structure for your project whatever you like -->

<!-- * **Elegant**: Epure allows structure of your project to be as complicated or simple as you want -->
<!-- * **Customizable**: Save your Epure in all forms and shapes -->
* **Convenient**: Many useful and intuitive tools, like Elist, Eset, JoinResource and many more
* **Fast**: Create tables based on your classes in no time
* **Concise**: Encourages efficient building of flexible and _smart_ queries
* **Simple, yet powerful**: Simple for novice, powerful for expert
</br>
</br>
<p align="center" style="font-size: 1.5rem">
    Please refer to our official documentation! 
</p>

<p align="center" style="font-size: 1.5rem"> <a href="https://epurelib.github.io/latest/" target="_blank">https://epurelib.github.io/latest/</a></p>
